@@ -19,7 +19,6 @@ package org.apache.commons.mail;
 import java.io.BufferedOutputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
-import java.io.FileWriter;
 import java.io.IOException;
 import java.util.Date;
 import java.util.Enumeration;
@@ -46,10 +45,10 @@ import org.subethamail.wiser.WiserMessage;
  * @since 1.0
  * @author <a href="mailto:corey.scott@gmail.com">Corey Scott</a>
  * @author <a href="mailto:epugh@opensourceconnections.com">Eric Pugh</a>
- * @version $Id: BaseEmailTestCase.java 544629 2007-06-05 20:55:13Z bspeakmon $
+ * @version $Id: BaseEmailTestCase.java 785799 2009-06-17 21:04:08Z sgoeschl $
  */
 
-public class BaseEmailTestCase extends TestCase
+public abstract class BaseEmailTestCase extends TestCase
 {
     /** Padding at end of body added by wiser/send */
     public static final int BODY_END_PAD = 3;
@@ -96,6 +95,9 @@ public class BaseEmailTestCase extends TestCase
     /** Where to save email output **/
     private File emailOutputDir;
 
+    /** counter for creating a file name */
+    private static int fileNameCounter;
+
     /**
      * @param name name
      */
@@ -132,17 +134,18 @@ public class BaseEmailTestCase extends TestCase
     }
 
     /**
+     * Safe a mail to a file using a more or less unique file name.
      *
      * @param email email
-     * @throws IOException Exception
+     * @throws IOException writing the email failed
+     * @throws MessagingException writing the email failed
      */
-    protected void saveEmailToFile(WiserMessage email) throws IOException
+    protected void saveEmailToFile(WiserMessage email) throws IOException, MessagingException
     {
-        File emailFile =
-            new File(emailOutputDir, "email" + new Date().getTime() + ".txt");
-        FileWriter fw = new FileWriter(emailFile);
-        fw.write(email.toString());
-        fw.close();
+        int currCounter = fileNameCounter++ % 10;
+        String emailFileName = "email" + new Date().getTime() + "-" + currCounter + ".eml";
+        File emailFile = new File(emailOutputDir, emailFileName);
+        EmailUtils.writeMimeMessage(emailFile, email.getMimeMessage() );
     }
 
     /**
@@ -236,7 +239,17 @@ public class BaseEmailTestCase extends TestCase
 
         if (boolSaveToFile)
         {
-            this.saveEmailToFile(emailMessage);
+            try
+            {
+                this.saveEmailToFile(emailMessage);
+            }
+            catch(MessagingException me)
+            {
+                IllegalStateException ise =
+                    new IllegalStateException("caught MessagingException during saving the email");
+                ise.initCause(me);
+                throw ise;
+            }
         }
 
         try
@@ -375,7 +388,7 @@ public class BaseEmailTestCase extends TestCase
      * passed in. The headers are serialized first followed by the message
      * body.
      *
-     * @param email The <code>WiserMessage</code> to serialize.
+     * @param wiserMessage The <code>WiserMessage</code> to serialize.
      * @return The string format of the message.
      * @throws MessagingException
      * @throws IOException
