@@ -17,7 +17,6 @@
 package org.apache.commons.mail.mocks;
 
 import java.io.IOException;
-import java.util.List;
 
 import javax.mail.MessagingException;
 import javax.mail.internet.InternetAddress;
@@ -30,7 +29,7 @@ import org.apache.commons.mail.MultiPartEmail;
  *
  * @since 1.0
  * @author <a href="mailto:corey.scott@gmail.com">Corey Scott</a>
- * @version $Id: MockMultiPartEmailConcrete.java 480401 2006-11-29 04:40:04Z bayard $
+ * @version $Id: MockMultiPartEmailConcrete.java 747572 2009-02-24 22:07:26Z sgoeschl $
  */
 public class MockMultiPartEmailConcrete extends MultiPartEmail
 {
@@ -70,28 +69,4 @@ public class MockMultiPartEmailConcrete extends MultiPartEmail
         return this.fromAddress;
     }
 
-    /**
-     * @return toList
-     */
-    public List getToList()
-    {
-        return this.toList;
-    }
-
-    /**
-     * @return bccList
-     */
-    public List getBccList()
-    {
-        return this.bccList;
-    }
-
-    /**
-     * @return ccList
-     */
-    public List getCcList()
-    {
-        return this.ccList;
-    }
-
 }
